@@ -1013,7 +1013,7 @@ if needed."
 	    proc)
 	(setq proc
 	      (apply 'start-process
-		     (concat " *" proc-name "-" (random t))
+		     (format " *%s-%d" proc-name (random t))
 		     buf
 		     (format (if gnats:network-server
 				 "%s/gnats/npr-edit"
